/**
  ******************************************************************************
  * @file    ADC2_ContinuousConversion\main.c
  * @author  MCD Application Team
  * @version  V2.2.0
  * @date     30-September-2014
  * @brief   This file contains the main function for the ADC2 Continuous Conversion example.
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8s.h"
#include "stm8s_eval.h"

  // * @addtogroup ADC2_ContinuousConversion

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
uint16_t Conversion_Value = 0;
// Private function prototypes -----------------------------------------------
static void ADC_Config(void);
static void GPIO_Config(void);
// Private functions ---------------------------------------------------------

/**
  * @brief ADC2_ContinuousConversion  main entry point.
  * @param  None
  * @retval None
  */
void main(void)
{
  // GPIO configuration ------------------------------------------
  GPIO_Config();

  // ADC configuration -------------------------------------------
  ADC_Config();
     
  // The LEDs state is changed in the interrupt routine 
  while (1);
}

/**
  * @brief  Configure ADC2 Continuous Conversion with End Of Conversion interrupt 
  *         enabled .
  * @param  None
  * @retval None
  */
static void ADC_Config()
{
  // Init GPIO for ADC2 
  GPIO_Init(GPIOE, GPIO_PIN_6, GPIO_MODE_IN_FL_NO_IT);
  
  // De-Init ADC peripheral
  ADC2_DeInit();

  // Init ADC2 peripheral 
  ADC2_Init(ADC2_CONVERSIONMODE_CONTINUOUS, ADC2_CHANNEL_9, ADC2_PRESSEL_FCPU_D2, \
            ADC2_EXTTRIG_TIM, DISABLE, ADC2_ALIGN_RIGHT, ADC2_SCHMITTTRIG_CHANNEL9,\
            DISABLE);

  // Enable EOC interrupt 
  ADC2_ITConfig(ENABLE);

  // Enable general interrupts   
  enableInterrupts();
  
  // Start Conversion 
  ADC2_StartConversion();
}

/**
  * @brief  Configure GPIO for LEDs and buttons available on the evaluation board
  * @param  None
  * @retval None
  */
static void GPIO_Config(void)
{
    // Initialize LEDs mounted on STM8-128 EVAL board 
    STM_EVAL_LEDInit(LED1);
    STM_EVAL_LEDInit(LED2);
    STM_EVAL_LEDInit(LED3);
    STM_EVAL_LEDInit(LED4);

}
 
#ifdef USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif



