/**
  ******************************************************************************
  * @file    CLK_ClockSecuritySystem\main.c
  * @author  MCD Application Team
  * @version  V2.2.0
  * @date     30-September-2014
  * @brief   This file contains the main function for the CLK CSS example.
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8s.h"
#include "stm8s_eval.h"

  // * @addtogroup CLK_ClockSecuritySystem

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
static void CLK_Config(void);
static void GPIO_Config(void);
void Delay(uint16_t nCount);
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
   uint16_t i = 0;

   // Init GPIO for LED  
   GPIO_Config();

   // CLK configuration --------------------------------------------
   CLK_Config();

   while (1)
   {
     // Toggle the LEDs  
     STM_EVAL_LEDToggle(LED1);
     STM_EVAL_LEDToggle(LED2);
     STM_EVAL_LEDToggle(LED3);
     STM_EVAL_LEDToggle(LED4);
     for (i = 0; i < 2; i++)
     {
         Delay((uint16_t)60000);
     }
   }
}

/**
  * @brief  Configure system clock to use HSE as source clock and to enable the 
  *         Clock Security System (CSS)  
  * @param  None
  * @retval None
  */
static void CLK_Config(void)
{
    ErrorStatus status = ERROR;
    
    CLK_DeInit();
    
    status = CLK_ClockSwitchConfig(CLK_SWITCHMODE_AUTO, CLK_SOURCE_HSE, DISABLE,
                                   CLK_CURRENTCLOCKSTATE_DISABLE);

    // Enable CSS interrupt 
    CLK_ITConfig(CLK_IT_CSSD, ENABLE);
    
    // Enable CCS 
    CLK_ClockSecuritySystemEnable();

    // Output Fcpu on CLK_CCO pin 
    CLK_CCOConfig(CLK_OUTPUT_MASTER);
    
    enableInterrupts();
}

/**
  * @brief  Configure GPIO for LEDs available on the evaluation board
  * @param  None
  * @retval None
  */
static void GPIO_Config(void)
{
    // Initialize LEDs mounted on STM8-128 EVAL board 
    STM_EVAL_LEDInit(LED1);
    STM_EVAL_LEDInit(LED2);
    STM_EVAL_LEDInit(LED3);
    STM_EVAL_LEDInit(LED4);
}

/**
  * @brief  Delay.
  * @param  nCount
  * @retval None
  */
void Delay(uint16_t nCount)
{
    // Decrement nCount value 
    while (nCount != 0)
    {
        nCount--;
    }
}


#ifdef USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif



