/**
  ******************************************************************************
  * @file    CLK_MaxSpeed\main.c
  * @author  MCD Application Team
  * @version  V2.2.0
  * @date     30-September-2014
  * @brief   This file contains the main function for the CLK Maximum Speed 
  *          configuration example.
  ******************************************************************************
  */ 

// Includes ------------------------------------------------------------------
#include "stm8s.h"
#include "stm8s_eval.h"

  // * @addtogroup CLK_MaxSpeed

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Public functions ----------------------------------------------------------
// Global variables ----------------------------------------------------------
bool ButtonPressed = FALSE;
// Private function prototypes -----------------------------------------------
static void GPIO_Config(void);
static void CLK_Config(void);
// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
void main(void)
{
    // GPIO Configuration  -----------------------------------------
    GPIO_Config();  
    
    // Clock configuration -----------------------------------------
    CLK_Config();    
    
    while (1)
    {
    }
}

/**
  * @brief  Configure GPIO for button available on the evaluation board
  * @param  None
  * @retval None
  */
static void GPIO_Config(void)
{
  // Configure GPIO used to drive KEY button 
    STM_EVAL_PBInit(BUTTON_KEY, BUTTON_MODE_EXTI);
    
    // Enable general interrupts 
    enableInterrupts();    
}

/**
  * @brief  Configure system clock to run at Maximum clock speed and output the 
  *         system clock on CCO pin
  * @param  None
  * @retval None
  */
static void CLK_Config(void)
{
    ErrorStatus status = FALSE;

    CLK_DeInit();

    // Configure the Fcpu to DIV1
    CLK_SYSCLKConfig(CLK_PRESCALER_CPUDIV1);
    
    // Configure the HSI prescaler to the optimal value 
    CLK_SYSCLKConfig(CLK_PRESCALER_HSIDIV1);

    // Output Fcpu on CLK_CCO pin 
    CLK_CCOConfig(CLK_OUTPUT_CPU);
        
    // Configure the system clock to use HSE clock source and to run at 24Mhz 
    status = CLK_ClockSwitchConfig(CLK_SWITCHMODE_AUTO, CLK_SOURCE_HSE, DISABLE, CLK_CURRENTCLOCKSTATE_DISABLE);
    
    while (ButtonPressed == FALSE)
    {
    }
    // Configure the system clock to use HSI clock source and to run at 16Mhz 
    status = CLK_ClockSwitchConfig(CLK_SWITCHMODE_AUTO, CLK_SOURCE_HSI, DISABLE, CLK_CURRENTCLOCKSTATE_DISABLE);
}

#ifdef USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *   where the assert_param error has occurred.
  * @param file: pointer to the source file name
  * @param line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif



